# polyaxon-sdk


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.12.0-rc2
- Package version: 2.12.0-rc2
- Build package: org.openapitools.codegen.languages.PythonNextgenClientCodegen
For more information, please visit [https://github.com/polyaxon/polyaxon](https://github.com/polyaxon/polyaxon)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import polyaxon_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import polyaxon_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import polyaxon_sdk
from polyaxon_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = polyaxon_sdk.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKey
configuration.api_key['ApiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKey'] = 'Bearer'


# Enter a context with an instance of the API client
with polyaxon_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = polyaxon_sdk.AgentsV1Api(api_client)
    namespace = 'namespace_example' # str | namespace
    owner = 'owner_example' # str | Owner of the namespace
    uuid = 'uuid_example' # str | Uuid identifier of the entity

    try:
        # collect agent
        api_response = api_instance.collect_agent_data(namespace, owner, uuid)
        print("The response of AgentsV1Api->collect_agent_data:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AgentsV1Api->collect_agent_data: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AgentsV1Api* | [**collect_agent_data**](docs/AgentsV1Api.md#collect_agent_data) | **POST** /internal/v1/{namespace}/{owner}/agents/{uuid}/collect | collect agent
*AgentsV1Api* | [**create_agent**](docs/AgentsV1Api.md#create_agent) | **POST** /api/v1/orgs/{owner}/agents | Create agent
*AgentsV1Api* | [**create_agent_status**](docs/AgentsV1Api.md#create_agent_status) | **POST** /api/v1/orgs/{owner}/agents/{uuid}/statuses | Create new agent status
*AgentsV1Api* | [**cron_agent**](docs/AgentsV1Api.md#cron_agent) | **POST** /api/v1/orgs/{owner}/agents/cron | Global Cron
*AgentsV1Api* | [**delete_agent**](docs/AgentsV1Api.md#delete_agent) | **DELETE** /api/v1/orgs/{owner}/agents/{uuid} | Delete agent
*AgentsV1Api* | [**get_agent**](docs/AgentsV1Api.md#get_agent) | **GET** /api/v1/orgs/{owner}/agents/{uuid} | Get agent
*AgentsV1Api* | [**get_agent_config**](docs/AgentsV1Api.md#get_agent_config) | **GET** /api/v1/orgs/{owner}/agents/{uuid}/config | Get agent config
*AgentsV1Api* | [**get_agent_logs**](docs/AgentsV1Api.md#get_agent_logs) | **GET** /streams/v1/{namespace}/{owner}/agents/{uuid}/logs | Get run logs
*AgentsV1Api* | [**get_agent_state**](docs/AgentsV1Api.md#get_agent_state) | **GET** /api/v1/orgs/{owner}/agents/{uuid}/state | Get State (queues/runs)
*AgentsV1Api* | [**get_agent_stats**](docs/AgentsV1Api.md#get_agent_stats) | **GET** /api/v1/orgs/{owner}/agents/{uuid}/stats | Get agent stats
*AgentsV1Api* | [**get_agent_statuses**](docs/AgentsV1Api.md#get_agent_statuses) | **GET** /api/v1/orgs/{owner}/agents/{uuid}/statuses | Get Agent statuses
*AgentsV1Api* | [**get_agent_token**](docs/AgentsV1Api.md#get_agent_token) | **GET** /api/v1/orgs/{owner}/agents/{uuid}/token | Get agent token
*AgentsV1Api* | [**get_global_state**](docs/AgentsV1Api.md#get_global_state) | **GET** /api/v1/orgs/{owner}/agents/state | Get Global State (queues/runs)
*AgentsV1Api* | [**inspect_agent**](docs/AgentsV1Api.md#inspect_agent) | **GET** /streams/v1/{namespace}/{owner}/agents/{uuid}/k8s_inspect | Inspect an agent&#39;s service full conditions
*AgentsV1Api* | [**list_agent_names**](docs/AgentsV1Api.md#list_agent_names) | **GET** /api/v1/orgs/{owner}/agents/names | List agents names
*AgentsV1Api* | [**list_agents**](docs/AgentsV1Api.md#list_agents) | **GET** /api/v1/orgs/{owner}/agents | List agents
*AgentsV1Api* | [**patch_agent**](docs/AgentsV1Api.md#patch_agent) | **PATCH** /api/v1/orgs/{owner}/agents/{agent.uuid} | Patch agent
*AgentsV1Api* | [**patch_agent_token**](docs/AgentsV1Api.md#patch_agent_token) | **PATCH** /api/v1/orgs/{owner}/agents/{entity}/token | Patch agent token
*AgentsV1Api* | [**reconcile_agent**](docs/AgentsV1Api.md#reconcile_agent) | **PATCH** /api/v1/orgs/{owner}/agents/{uuid}/reconcile | Reconcile agent
*AgentsV1Api* | [**sync_agent**](docs/AgentsV1Api.md#sync_agent) | **PATCH** /api/v1/orgs/{owner}/agents/{agent.uuid}/sync | Sync agent
*AgentsV1Api* | [**update_agent**](docs/AgentsV1Api.md#update_agent) | **PUT** /api/v1/orgs/{owner}/agents/{agent.uuid} | Update agent
*AgentsV1Api* | [**update_agent_config**](docs/AgentsV1Api.md#update_agent_config) | **PATCH** /api/v1/orgs/{owner}/agents/{agent.uuid}/config | Update agent config
*AgentsV1Api* | [**update_agent_token**](docs/AgentsV1Api.md#update_agent_token) | **PUT** /api/v1/orgs/{owner}/agents/{entity}/token | Update agent token
*ArtifactsStoresV1Api* | [**upload_artifact**](docs/ArtifactsStoresV1Api.md#upload_artifact) | **POST** /api/v1/catalogs/{owner}/artifacts/{uuid}/upload | Upload artifact to a store
*AuthV1Api* | [**change_password**](docs/AuthV1Api.md#change_password) | **POST** /api/v1/auth/change-password | Change password
*AuthV1Api* | [**login**](docs/AuthV1Api.md#login) | **POST** /api/v1/auth/token | Login
*AuthV1Api* | [**reset_password**](docs/AuthV1Api.md#reset_password) | **POST** /api/v1/auth/reset-password | Reset password
*AuthV1Api* | [**reset_password_confirm**](docs/AuthV1Api.md#reset_password_confirm) | **POST** /api/v1/auth/reset-password-confirm | Reset password confirm
*AuthV1Api* | [**signup**](docs/AuthV1Api.md#signup) | **POST** /api/v1/auth/signup | Signup
*AuthV1Api* | [**trial**](docs/AuthV1Api.md#trial) | **POST** /api/v1/auth/trial | Trial Start
*ConnectionsV1Api* | [**create_connection**](docs/ConnectionsV1Api.md#create_connection) | **POST** /api/v1/orgs/{owner}/connections | Create connection
*ConnectionsV1Api* | [**delete_connection**](docs/ConnectionsV1Api.md#delete_connection) | **DELETE** /api/v1/orgs/{owner}/connections/{uuid} | Delete connection
*ConnectionsV1Api* | [**get_connection**](docs/ConnectionsV1Api.md#get_connection) | **GET** /api/v1/orgs/{owner}/connections/{uuid} | Get connection
*ConnectionsV1Api* | [**list_connection_names**](docs/ConnectionsV1Api.md#list_connection_names) | **GET** /api/v1/orgs/{owner}/connections/names | List connections names
*ConnectionsV1Api* | [**list_connections**](docs/ConnectionsV1Api.md#list_connections) | **GET** /api/v1/orgs/{owner}/connections | List connections
*ConnectionsV1Api* | [**patch_connection**](docs/ConnectionsV1Api.md#patch_connection) | **PATCH** /api/v1/orgs/{owner}/connections/{connection.uuid} | Patch connection
*ConnectionsV1Api* | [**update_connection**](docs/ConnectionsV1Api.md#update_connection) | **PUT** /api/v1/orgs/{owner}/connections/{connection.uuid} | Update connection
*DashboardsV1Api* | [**create_dashboard**](docs/DashboardsV1Api.md#create_dashboard) | **POST** /api/v1/orgs/{owner}/dashboards | Create dashboard
*DashboardsV1Api* | [**delete_dashboard**](docs/DashboardsV1Api.md#delete_dashboard) | **DELETE** /api/v1/orgs/{owner}/dashboards/{uuid} | Delete dashboard
*DashboardsV1Api* | [**get_dashboard**](docs/DashboardsV1Api.md#get_dashboard) | **GET** /api/v1/orgs/{owner}/dashboards/{uuid} | Get dashboard
*DashboardsV1Api* | [**list_dashboard_names**](docs/DashboardsV1Api.md#list_dashboard_names) | **GET** /api/v1/orgs/{owner}/dashboards/names | List dashboard names
*DashboardsV1Api* | [**list_dashboards**](docs/DashboardsV1Api.md#list_dashboards) | **GET** /api/v1/orgs/{owner}/dashboards | List dashboards
*DashboardsV1Api* | [**patch_dashboard**](docs/DashboardsV1Api.md#patch_dashboard) | **PATCH** /api/v1/orgs/{owner}/dashboards/{dashboard.uuid} | Patch dashboard
*DashboardsV1Api* | [**update_dashboard**](docs/DashboardsV1Api.md#update_dashboard) | **PUT** /api/v1/orgs/{owner}/dashboards/{dashboard.uuid} | Update dashboard
*OrganizationsV1Api* | [**approve_organization_runs**](docs/OrganizationsV1Api.md#approve_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/approve | Approve cross-project runs selection
*OrganizationsV1Api* | [**archive_organization_runs**](docs/OrganizationsV1Api.md#archive_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/archive | Archive cross-project runs selection
*OrganizationsV1Api* | [**bookmark_organization_runs**](docs/OrganizationsV1Api.md#bookmark_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/bookmark | Bookmark cross-project runs selection
*OrganizationsV1Api* | [**create_organization**](docs/OrganizationsV1Api.md#create_organization) | **POST** /api/v1/orgs/create | Create organization
*OrganizationsV1Api* | [**create_organization_member**](docs/OrganizationsV1Api.md#create_organization_member) | **POST** /api/v1/orgs/{owner}/members | Create organization member
*OrganizationsV1Api* | [**delete_organization**](docs/OrganizationsV1Api.md#delete_organization) | **DELETE** /api/v1/orgs/{owner} | Delete organization
*OrganizationsV1Api* | [**delete_organization_invitation**](docs/OrganizationsV1Api.md#delete_organization_invitation) | **DELETE** /api/v1/orgs/{owner}/invitations | Delete organization invitation details
*OrganizationsV1Api* | [**delete_organization_member**](docs/OrganizationsV1Api.md#delete_organization_member) | **DELETE** /api/v1/orgs/{owner}/members/{name} | Delete organization member details
*OrganizationsV1Api* | [**delete_organization_runs**](docs/OrganizationsV1Api.md#delete_organization_runs) | **DELETE** /api/v1/orgs/{owner}/runs/delete | Delete cross-project runs selection
*OrganizationsV1Api* | [**get_organization**](docs/OrganizationsV1Api.md#get_organization) | **GET** /api/v1/orgs/{owner} | Get organization
*OrganizationsV1Api* | [**get_organization_activities**](docs/OrganizationsV1Api.md#get_organization_activities) | **GET** /api/v1/orgs/{owner}/activities | Get organization activities
*OrganizationsV1Api* | [**get_organization_invitation**](docs/OrganizationsV1Api.md#get_organization_invitation) | **GET** /api/v1/orgs/{owner}/invitations | Get organization invitation details
*OrganizationsV1Api* | [**get_organization_member**](docs/OrganizationsV1Api.md#get_organization_member) | **GET** /api/v1/orgs/{owner}/members/{name} | Get organization member details
*OrganizationsV1Api* | [**get_organization_multi_run_events**](docs/OrganizationsV1Api.md#get_organization_multi_run_events) | **GET** /streams/v1/{namespace}/orgs/{owner}/runs/multi/events/{kind} | Get multi runs events
*OrganizationsV1Api* | [**get_organization_multi_run_importance**](docs/OrganizationsV1Api.md#get_organization_multi_run_importance) | **POST** /streams/v1/{namespace}/orgs/{owner}/runs/multi/importance | Get multi run importance
*OrganizationsV1Api* | [**get_organization_run**](docs/OrganizationsV1Api.md#get_organization_run) | **GET** /api/v1/orgs/{owner}/runs/{uuid} | Get a run in an organization
*OrganizationsV1Api* | [**get_organization_runs**](docs/OrganizationsV1Api.md#get_organization_runs) | **GET** /api/v1/orgs/{owner}/runs | Get all runs in an organization
*OrganizationsV1Api* | [**get_organization_runs_artifacts_lineage**](docs/OrganizationsV1Api.md#get_organization_runs_artifacts_lineage) | **GET** /api/v1/orgs/{owner}/runs/lineage/artifacts | Get runs artifacts lineage
*OrganizationsV1Api* | [**get_organization_settings**](docs/OrganizationsV1Api.md#get_organization_settings) | **GET** /api/v1/orgs/{owner}/settings | Get organization settings
*OrganizationsV1Api* | [**get_organization_stats**](docs/OrganizationsV1Api.md#get_organization_stats) | **GET** /api/v1/orgs/{owner}/stats | Get organization stats
*OrganizationsV1Api* | [**get_organization_versions**](docs/OrganizationsV1Api.md#get_organization_versions) | **GET** /api/v1/orgs/{owner}/versions/{kind} | Get all runs in an organization
*OrganizationsV1Api* | [**invalidate_organization_runs**](docs/OrganizationsV1Api.md#invalidate_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/invalidate | Invalidate cross-project runs selection
*OrganizationsV1Api* | [**list_organization_member_names**](docs/OrganizationsV1Api.md#list_organization_member_names) | **GET** /api/v1/orgs/{owner}/members/names | Get organization member names
*OrganizationsV1Api* | [**list_organization_members**](docs/OrganizationsV1Api.md#list_organization_members) | **GET** /api/v1/orgs/{owner}/members | Get organization members
*OrganizationsV1Api* | [**list_organization_names**](docs/OrganizationsV1Api.md#list_organization_names) | **GET** /api/v1/orgs/names | List organizations names
*OrganizationsV1Api* | [**list_organizations**](docs/OrganizationsV1Api.md#list_organizations) | **GET** /api/v1/orgs/list | List organizations
*OrganizationsV1Api* | [**organization_license**](docs/OrganizationsV1Api.md#organization_license) | **POST** /api/v1/orgs/{owner}/license | Organization license
*OrganizationsV1Api* | [**organization_plan**](docs/OrganizationsV1Api.md#organization_plan) | **POST** /api/v1/orgs/{owner}/plan | Organization plan
*OrganizationsV1Api* | [**patch_organization**](docs/OrganizationsV1Api.md#patch_organization) | **PATCH** /api/v1/orgs/{owner} | Patch organization
*OrganizationsV1Api* | [**patch_organization_invitation**](docs/OrganizationsV1Api.md#patch_organization_invitation) | **PATCH** /api/v1/orgs/{owner}/invitations | Patch organization invitation
*OrganizationsV1Api* | [**patch_organization_member**](docs/OrganizationsV1Api.md#patch_organization_member) | **PATCH** /api/v1/orgs/{owner}/members/{member.user} | Patch organization member
*OrganizationsV1Api* | [**patch_organization_settings**](docs/OrganizationsV1Api.md#patch_organization_settings) | **PATCH** /api/v1/orgs/{owner}/settings | Patch oranization settings
*OrganizationsV1Api* | [**resend_organization_invitation**](docs/OrganizationsV1Api.md#resend_organization_invitation) | **POST** /api/v1/orgs/{owner}/invitations | Resend organization invitation
*OrganizationsV1Api* | [**restore_organization_runs**](docs/OrganizationsV1Api.md#restore_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/restore | Restore cross-project runs selection
*OrganizationsV1Api* | [**skip_organization_runs**](docs/OrganizationsV1Api.md#skip_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/Skip | Skip cross-project runs selection
*OrganizationsV1Api* | [**stop_organization_runs**](docs/OrganizationsV1Api.md#stop_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/stop | Stop cross-project runs selection
*OrganizationsV1Api* | [**tag_organization_runs**](docs/OrganizationsV1Api.md#tag_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/tag | Tag cross-project runs selection
*OrganizationsV1Api* | [**transfer_organization_runs**](docs/OrganizationsV1Api.md#transfer_organization_runs) | **POST** /api/v1/orgs/{owner}/runs/transfer | Transfer cross-project runs selection to a new project
*OrganizationsV1Api* | [**update_organization**](docs/OrganizationsV1Api.md#update_organization) | **PUT** /api/v1/orgs/{owner} | Update organization
*OrganizationsV1Api* | [**update_organization_invitation**](docs/OrganizationsV1Api.md#update_organization_invitation) | **PUT** /api/v1/orgs/{owner}/invitations | Update organization invitation
*OrganizationsV1Api* | [**update_organization_member**](docs/OrganizationsV1Api.md#update_organization_member) | **PUT** /api/v1/orgs/{owner}/members/{member.user} | Update organization member
*OrganizationsV1Api* | [**update_organization_settings**](docs/OrganizationsV1Api.md#update_organization_settings) | **PUT** /api/v1/orgs/{owner}/settings | Update organization settings
*PoliciesV1Api* | [**create_policy**](docs/PoliciesV1Api.md#create_policy) | **POST** /api/v1/orgs/{owner}/policies | Create Policy
*PoliciesV1Api* | [**delete_policy**](docs/PoliciesV1Api.md#delete_policy) | **DELETE** /api/v1/orgs/{owner}/policies/{uuid} | Delete scheduling preset
*PoliciesV1Api* | [**get_policy**](docs/PoliciesV1Api.md#get_policy) | **GET** /api/v1/orgs/{owner}/policies/{uuid} | Get Policy
*PoliciesV1Api* | [**list_policies**](docs/PoliciesV1Api.md#list_policies) | **GET** /api/v1/orgs/{owner}/policies | List Policies
*PoliciesV1Api* | [**list_policy_names**](docs/PoliciesV1Api.md#list_policy_names) | **GET** /api/v1/orgs/{owner}/policies/names | List scheduling policies names
*PoliciesV1Api* | [**patch_policy**](docs/PoliciesV1Api.md#patch_policy) | **PATCH** /api/v1/orgs/{owner}/policies/{policy.uuid} | Patch Policy
*PoliciesV1Api* | [**update_policy**](docs/PoliciesV1Api.md#update_policy) | **PUT** /api/v1/orgs/{owner}/policies/{policy.uuid} | Update Policy
*PresetsV1Api* | [**create_preset**](docs/PresetsV1Api.md#create_preset) | **POST** /api/v1/orgs/{owner}/presets | Create scheduling presets
*PresetsV1Api* | [**delete_preset**](docs/PresetsV1Api.md#delete_preset) | **DELETE** /api/v1/orgs/{owner}/presets/{uuid} | Delete scheduling preset
*PresetsV1Api* | [**get_preset**](docs/PresetsV1Api.md#get_preset) | **GET** /api/v1/orgs/{owner}/presets/{uuid} | Get scheduling preset
*PresetsV1Api* | [**list_preset_names**](docs/PresetsV1Api.md#list_preset_names) | **GET** /api/v1/orgs/{owner}/presets/names | List scheduling presets names
*PresetsV1Api* | [**list_presets**](docs/PresetsV1Api.md#list_presets) | **GET** /api/v1/orgs/{owner}/presets | List scheduling presets
*PresetsV1Api* | [**patch_preset**](docs/PresetsV1Api.md#patch_preset) | **PATCH** /api/v1/orgs/{owner}/presets/{preset.uuid} | Patch scheduling preset
*PresetsV1Api* | [**update_preset**](docs/PresetsV1Api.md#update_preset) | **PUT** /api/v1/orgs/{owner}/presets/{preset.uuid} | Update scheduling preset
*ProjectDashboardsV1Api* | [**create_project_dashboard**](docs/ProjectDashboardsV1Api.md#create_project_dashboard) | **POST** /api/v1/{owner}/{project}/dashboards | Create project dashboard
*ProjectDashboardsV1Api* | [**delete_project_dashboard**](docs/ProjectDashboardsV1Api.md#delete_project_dashboard) | **DELETE** /api/v1/{owner}/{entity}/dashboards/{uuid} | Delete project dashboard
*ProjectDashboardsV1Api* | [**get_project_dashboard**](docs/ProjectDashboardsV1Api.md#get_project_dashboard) | **GET** /api/v1/{owner}/{entity}/dashboards/{uuid} | Get project dashboard
*ProjectDashboardsV1Api* | [**list_project_dashboard_names**](docs/ProjectDashboardsV1Api.md#list_project_dashboard_names) | **GET** /api/v1/{owner}/{name}/dashboards/names | List project dashboard
*ProjectDashboardsV1Api* | [**list_project_dashboards**](docs/ProjectDashboardsV1Api.md#list_project_dashboards) | **GET** /api/v1/{owner}/{name}/dashboards | List project dashboards
*ProjectDashboardsV1Api* | [**patch_project_dashboard**](docs/ProjectDashboardsV1Api.md#patch_project_dashboard) | **PATCH** /api/v1/{owner}/{project}/dashboards/{dashboard.uuid} | Patch project dashboard
*ProjectDashboardsV1Api* | [**promote_project_dashboard**](docs/ProjectDashboardsV1Api.md#promote_project_dashboard) | **POST** /api/v1/{owner}/{entity}/dashboards/{uuid}/promote | Promote project dashboard
*ProjectDashboardsV1Api* | [**update_project_dashboard**](docs/ProjectDashboardsV1Api.md#update_project_dashboard) | **PUT** /api/v1/{owner}/{project}/dashboards/{dashboard.uuid} | Update project dashboard
*ProjectSearchesV1Api* | [**create_project_search**](docs/ProjectSearchesV1Api.md#create_project_search) | **POST** /api/v1/{owner}/{project}/searches | Create project search
*ProjectSearchesV1Api* | [**delete_project_search**](docs/ProjectSearchesV1Api.md#delete_project_search) | **DELETE** /api/v1/{owner}/{entity}/searches/{uuid} | Delete project search
*ProjectSearchesV1Api* | [**get_project_search**](docs/ProjectSearchesV1Api.md#get_project_search) | **GET** /api/v1/{owner}/{entity}/searches/{uuid} | Get project search
*ProjectSearchesV1Api* | [**list_project_search_names**](docs/ProjectSearchesV1Api.md#list_project_search_names) | **GET** /api/v1/{owner}/{name}/searches/names | List project search names
*ProjectSearchesV1Api* | [**list_project_searches**](docs/ProjectSearchesV1Api.md#list_project_searches) | **GET** /api/v1/{owner}/{name}/searches | List project searches
*ProjectSearchesV1Api* | [**patch_project_search**](docs/ProjectSearchesV1Api.md#patch_project_search) | **PATCH** /api/v1/{owner}/{project}/searches/{search.uuid} | Patch project search
*ProjectSearchesV1Api* | [**promote_project_search**](docs/ProjectSearchesV1Api.md#promote_project_search) | **POST** /api/v1/{owner}/{entity}/searches/{uuid}/promote | Promote project search
*ProjectSearchesV1Api* | [**update_project_search**](docs/ProjectSearchesV1Api.md#update_project_search) | **PUT** /api/v1/{owner}/{project}/searches/{search.uuid} | Update project search
*ProjectsV1Api* | [**archive_project**](docs/ProjectsV1Api.md#archive_project) | **POST** /api/v1/{owner}/{name}/archive | Archive project
*ProjectsV1Api* | [**bookmark_project**](docs/ProjectsV1Api.md#bookmark_project) | **POST** /api/v1/{owner}/{name}/bookmark | Bookmark project
*ProjectsV1Api* | [**create_project**](docs/ProjectsV1Api.md#create_project) | **POST** /api/v1/{owner}/projects/create | Create new project
*ProjectsV1Api* | [**create_team_project**](docs/ProjectsV1Api.md#create_team_project) | **POST** /api/v1/{owner}/{team}/projects/create | Create new project via team space
*ProjectsV1Api* | [**create_version**](docs/ProjectsV1Api.md#create_version) | **POST** /api/v1/{owner}/{project}/versions/{version.kind} | Create version
*ProjectsV1Api* | [**create_version_stage**](docs/ProjectsV1Api.md#create_version_stage) | **POST** /api/v1/{owner}/{entity}/versions/{kind}/{name}/stages | Create new artifact version stage
*ProjectsV1Api* | [**delete_project**](docs/ProjectsV1Api.md#delete_project) | **DELETE** /api/v1/{owner}/{name} | Delete project
*ProjectsV1Api* | [**delete_version**](docs/ProjectsV1Api.md#delete_version) | **DELETE** /api/v1/{owner}/{entity}/versions/{kind}/{name} | Delete version
*ProjectsV1Api* | [**disable_project_ci**](docs/ProjectsV1Api.md#disable_project_ci) | **DELETE** /api/v1/{owner}/{name}/ci | Disbale project CI
*ProjectsV1Api* | [**enable_project_ci**](docs/ProjectsV1Api.md#enable_project_ci) | **POST** /api/v1/{owner}/{name}/ci | Enable project CI
*ProjectsV1Api* | [**get_project**](docs/ProjectsV1Api.md#get_project) | **GET** /api/v1/{owner}/{name} | Get project
*ProjectsV1Api* | [**get_project_activities**](docs/ProjectsV1Api.md#get_project_activities) | **GET** /api/v1/{owner}/{name}/activities | Get project activities
*ProjectsV1Api* | [**get_project_settings**](docs/ProjectsV1Api.md#get_project_settings) | **GET** /api/v1/{owner}/{name}/settings | Get Project settings
*ProjectsV1Api* | [**get_project_stats**](docs/ProjectsV1Api.md#get_project_stats) | **GET** /api/v1/{owner}/{name}/stats | Get project stats
*ProjectsV1Api* | [**get_version**](docs/ProjectsV1Api.md#get_version) | **GET** /api/v1/{owner}/{entity}/versions/{kind}/{name} | Get version
*ProjectsV1Api* | [**get_version_stages**](docs/ProjectsV1Api.md#get_version_stages) | **GET** /api/v1/{owner}/{entity}/versions/{kind}/{name}/stages | Get version stages
*ProjectsV1Api* | [**list_archived_projects**](docs/ProjectsV1Api.md#list_archived_projects) | **GET** /api/v1/archives/{user}/projects | List archived projects for user
*ProjectsV1Api* | [**list_bookmarked_projects**](docs/ProjectsV1Api.md#list_bookmarked_projects) | **GET** /api/v1/bookmarks/{user}/projects | List bookmarked projects for user
*ProjectsV1Api* | [**list_project_names**](docs/ProjectsV1Api.md#list_project_names) | **GET** /api/v1/{owner}/projects/names | List project names
*ProjectsV1Api* | [**list_projects**](docs/ProjectsV1Api.md#list_projects) | **GET** /api/v1/{owner}/projects/list | List projects
*ProjectsV1Api* | [**list_version_names**](docs/ProjectsV1Api.md#list_version_names) | **GET** /api/v1/{owner}/{entity}/versions/{kind}/names | List versions names
*ProjectsV1Api* | [**list_versions**](docs/ProjectsV1Api.md#list_versions) | **GET** /api/v1/{owner}/{entity}/versions/{kind} | List versions
*ProjectsV1Api* | [**patch_project**](docs/ProjectsV1Api.md#patch_project) | **PATCH** /api/v1/{owner}/{project.name} | Patch project
*ProjectsV1Api* | [**patch_project_settings**](docs/ProjectsV1Api.md#patch_project_settings) | **PATCH** /api/v1/{owner}/{project}/settings | Patch project settings
*ProjectsV1Api* | [**patch_version**](docs/ProjectsV1Api.md#patch_version) | **PATCH** /api/v1/{owner}/{project}/versions/{version.kind}/{version.name} | Patch version
*ProjectsV1Api* | [**restore_project**](docs/ProjectsV1Api.md#restore_project) | **POST** /api/v1/{owner}/{name}/restore | Restore project
*ProjectsV1Api* | [**transfer_version**](docs/ProjectsV1Api.md#transfer_version) | **POST** /api/v1/{owner}/{project}/versions/{version.kind}/{version.name}/transfer | Transfer version
*ProjectsV1Api* | [**unbookmark_project**](docs/ProjectsV1Api.md#unbookmark_project) | **DELETE** /api/v1/{owner}/{name}/unbookmark | Unbookmark project
*ProjectsV1Api* | [**update_project**](docs/ProjectsV1Api.md#update_project) | **PUT** /api/v1/{owner}/{project.name} | Update project
*ProjectsV1Api* | [**update_project_settings**](docs/ProjectsV1Api.md#update_project_settings) | **PUT** /api/v1/{owner}/{project}/settings | Update project settings
*ProjectsV1Api* | [**update_version**](docs/ProjectsV1Api.md#update_version) | **PUT** /api/v1/{owner}/{project}/versions/{version.kind}/{version.name} | Update version
*ProjectsV1Api* | [**upload_project_artifact**](docs/ProjectsV1Api.md#upload_project_artifact) | **POST** /api/v1/{owner}/{project}/artifacts/{uuid}/upload | Upload artifact to a store via project access
*QueuesV1Api* | [**create_queue**](docs/QueuesV1Api.md#create_queue) | **POST** /api/v1/orgs/{owner}/agents/{agent}/queues | Create queue
*QueuesV1Api* | [**delete_queue**](docs/QueuesV1Api.md#delete_queue) | **DELETE** /api/v1/orgs/{owner}/agents/{entity}/queues/{uuid} | Delete queue
*QueuesV1Api* | [**get_queue**](docs/QueuesV1Api.md#get_queue) | **GET** /api/v1/orgs/{owner}/agents/{entity}/queues/{uuid} | Get queue
*QueuesV1Api* | [**get_queue_stats**](docs/QueuesV1Api.md#get_queue_stats) | **GET** /api/v1/orgs/{owner}/agents/{entity}/queues/{uuid}/stats | Get queue stats
*QueuesV1Api* | [**list_organization_queue_names**](docs/QueuesV1Api.md#list_organization_queue_names) | **GET** /api/v1/orgs/{owner}/queues/names | List organization level queues names
*QueuesV1Api* | [**list_organization_queues**](docs/QueuesV1Api.md#list_organization_queues) | **GET** /api/v1/orgs/{owner}/queues | List organization level queues
*QueuesV1Api* | [**list_queue_names**](docs/QueuesV1Api.md#list_queue_names) | **GET** /api/v1/orgs/{owner}/agents/{name}/queues/names | List queues names
*QueuesV1Api* | [**list_queues**](docs/QueuesV1Api.md#list_queues) | **GET** /api/v1/orgs/{owner}/agents/{name}/queues | List queues
*QueuesV1Api* | [**patch_queue**](docs/QueuesV1Api.md#patch_queue) | **PATCH** /api/v1/orgs/{owner}/agents/{agent}/queues/{queue.uuid} | Patch queue
*QueuesV1Api* | [**update_queue**](docs/QueuesV1Api.md#update_queue) | **PUT** /api/v1/orgs/{owner}/agents/{agent}/queues/{queue.uuid} | Update queue
*RunsV1Api* | [**approve_run**](docs/RunsV1Api.md#approve_run) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/approve | Approve run
*RunsV1Api* | [**approve_runs**](docs/RunsV1Api.md#approve_runs) | **POST** /api/v1/{owner}/{name}/runs/approve | Approve runs
*RunsV1Api* | [**archive_run**](docs/RunsV1Api.md#archive_run) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/archive | Archive run
*RunsV1Api* | [**archive_runs**](docs/RunsV1Api.md#archive_runs) | **POST** /api/v1/{owner}/{name}/runs/archive | Archive runs
*RunsV1Api* | [**bookmark_run**](docs/RunsV1Api.md#bookmark_run) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/bookmark | Bookmark run
*RunsV1Api* | [**bookmark_runs**](docs/RunsV1Api.md#bookmark_runs) | **POST** /api/v1/{owner}/{name}/runs/bookmark | Bookmark runs
*RunsV1Api* | [**collect_run_logs**](docs/RunsV1Api.md#collect_run_logs) | **POST** /internal/v1/{namespace}/{owner}/{project}/runs/{uuid}/{kind}/logs | Internal API to collect run logs
*RunsV1Api* | [**copy_run**](docs/RunsV1Api.md#copy_run) | **POST** /api/v1/{owner}/{project}/runs/{run.uuid}/copy | Restart run with copy
*RunsV1Api* | [**create_run**](docs/RunsV1Api.md#create_run) | **POST** /api/v1/{owner}/{project}/runs | Create new run
*RunsV1Api* | [**create_run_artifacts_lineage**](docs/RunsV1Api.md#create_run_artifacts_lineage) | **POST** /api/v1/{owner}/{project}/runs/{uuid}/lineage/artifacts | Create bulk run artifacts lineage
*RunsV1Api* | [**create_run_status**](docs/RunsV1Api.md#create_run_status) | **POST** /api/v1/{owner}/{project}/runs/{uuid}/statuses | Create new run status
*RunsV1Api* | [**delete_run**](docs/RunsV1Api.md#delete_run) | **DELETE** /api/v1/{owner}/{entity}/runs/{uuid} | Delete run
*RunsV1Api* | [**delete_run_artifact**](docs/RunsV1Api.md#delete_run_artifact) | **DELETE** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifact | Delete run artifact
*RunsV1Api* | [**delete_run_artifact_lineage**](docs/RunsV1Api.md#delete_run_artifact_lineage) | **DELETE** /api/v1/{owner}/{project}/runs/{uuid}/lineage/artifacts/{name} | Delete run artifact lineage
*RunsV1Api* | [**delete_run_artifacts**](docs/RunsV1Api.md#delete_run_artifacts) | **DELETE** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifacts | Delete run artifacts
*RunsV1Api* | [**delete_runs**](docs/RunsV1Api.md#delete_runs) | **DELETE** /api/v1/{owner}/{name}/runs/delete | Delete runs
*RunsV1Api* | [**get_multi_run_events**](docs/RunsV1Api.md#get_multi_run_events) | **GET** /streams/v1/{namespace}/{owner}/{entity}/runs/multi/events/{kind} | Get multi runs events
*RunsV1Api* | [**get_multi_run_importance**](docs/RunsV1Api.md#get_multi_run_importance) | **POST** /streams/v1/{namespace}/{owner}/{entity}/runs/multi/importance | Get multi run importance
*RunsV1Api* | [**get_run**](docs/RunsV1Api.md#get_run) | **GET** /api/v1/{owner}/{entity}/runs/{uuid} | Get run
*RunsV1Api* | [**get_run_artifact**](docs/RunsV1Api.md#get_run_artifact) | **GET** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifact | Get run artifact
*RunsV1Api* | [**get_run_artifact_lineage**](docs/RunsV1Api.md#get_run_artifact_lineage) | **GET** /api/v1/{owner}/{project}/runs/{uuid}/lineage/artifacts/{name} | Get run artifacts lineage
*RunsV1Api* | [**get_run_artifacts**](docs/RunsV1Api.md#get_run_artifacts) | **GET** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifacts | Get run artifacts
*RunsV1Api* | [**get_run_artifacts_lineage**](docs/RunsV1Api.md#get_run_artifacts_lineage) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/lineage/artifacts | Get run artifacts lineage
*RunsV1Api* | [**get_run_artifacts_lineage_names**](docs/RunsV1Api.md#get_run_artifacts_lineage_names) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/lineage/artifacts/names | Get run artifacts lineage names
*RunsV1Api* | [**get_run_artifacts_tree**](docs/RunsV1Api.md#get_run_artifacts_tree) | **GET** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifacts/tree | Get run artifacts tree
*RunsV1Api* | [**get_run_clones_lineage**](docs/RunsV1Api.md#get_run_clones_lineage) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/lineage/clones | Get run clones lineage
*RunsV1Api* | [**get_run_connections_lineage**](docs/RunsV1Api.md#get_run_connections_lineage) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/lineage/connections | Get run connections lineage
*RunsV1Api* | [**get_run_downstream_lineage**](docs/RunsV1Api.md#get_run_downstream_lineage) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/lineage/downstream | Get run downstream lineage
*RunsV1Api* | [**get_run_events**](docs/RunsV1Api.md#get_run_events) | **GET** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/events/{kind} | Get run events
*RunsV1Api* | [**get_run_logs**](docs/RunsV1Api.md#get_run_logs) | **GET** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/logs | Get run logs
*RunsV1Api* | [**get_run_namespace**](docs/RunsV1Api.md#get_run_namespace) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/namespace | Get Run namespace
*RunsV1Api* | [**get_run_resources**](docs/RunsV1Api.md#get_run_resources) | **GET** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/resources | Get run resources events
*RunsV1Api* | [**get_run_settings**](docs/RunsV1Api.md#get_run_settings) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/settings | Get Run settings
*RunsV1Api* | [**get_run_stats**](docs/RunsV1Api.md#get_run_stats) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/stats | Get run stats
*RunsV1Api* | [**get_run_statuses**](docs/RunsV1Api.md#get_run_statuses) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/statuses | Get run statuses
*RunsV1Api* | [**get_run_upstream_lineage**](docs/RunsV1Api.md#get_run_upstream_lineage) | **GET** /api/v1/{owner}/{entity}/runs/{uuid}/lineage/upstream | Get run upstream lineage
*RunsV1Api* | [**get_runs_artifacts_lineage**](docs/RunsV1Api.md#get_runs_artifacts_lineage) | **GET** /api/v1/{owner}/{name}/runs/lineage/artifacts | Get runs artifacts lineage
*RunsV1Api* | [**impersonate_token**](docs/RunsV1Api.md#impersonate_token) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/impersonate | Impersonate run token
*RunsV1Api* | [**inspect_run**](docs/RunsV1Api.md#inspect_run) | **GET** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/k8s_inspect | Inspect an active run full conditions
*RunsV1Api* | [**invalidate_run**](docs/RunsV1Api.md#invalidate_run) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/invalidate | Invalidate run
*RunsV1Api* | [**invalidate_runs**](docs/RunsV1Api.md#invalidate_runs) | **POST** /api/v1/{owner}/{name}/runs/invalidate | Invalidate runs
*RunsV1Api* | [**list_archived_runs**](docs/RunsV1Api.md#list_archived_runs) | **GET** /api/v1/archives/{user}/runs | List archived runs for user
*RunsV1Api* | [**list_bookmarked_runs**](docs/RunsV1Api.md#list_bookmarked_runs) | **GET** /api/v1/bookmarks/{user}/runs | List bookmarked runs for user
*RunsV1Api* | [**list_runs**](docs/RunsV1Api.md#list_runs) | **GET** /api/v1/{owner}/{name}/runs | List runs
*RunsV1Api* | [**notify_run_status**](docs/RunsV1Api.md#notify_run_status) | **POST** /streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/notify | Notify run status
*RunsV1Api* | [**patch_run**](docs/RunsV1Api.md#patch_run) | **PATCH** /api/v1/{owner}/{project}/runs/{run.uuid} | Patch run
*RunsV1Api* | [**restart_run**](docs/RunsV1Api.md#restart_run) | **POST** /api/v1/{owner}/{project}/runs/{run.uuid}/restart | Restart run
*RunsV1Api* | [**restore_run**](docs/RunsV1Api.md#restore_run) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/restore | Restore run
*RunsV1Api* | [**restore_runs**](docs/RunsV1Api.md#restore_runs) | **POST** /api/v1/{owner}/{name}/runs/restore | Restore runs
*RunsV1Api* | [**resume_run**](docs/RunsV1Api.md#resume_run) | **POST** /api/v1/{owner}/{project}/runs/{run.uuid}/resume | Resume run
*RunsV1Api* | [**set_run_edges_lineage**](docs/RunsV1Api.md#set_run_edges_lineage) | **POST** /api/v1/{owner}/{project}/runs/{uuid}/lineage/edges | Set run edges graph lineage
*RunsV1Api* | [**skip_run**](docs/RunsV1Api.md#skip_run) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/skip | Skip run
*RunsV1Api* | [**skip_runs**](docs/RunsV1Api.md#skip_runs) | **POST** /api/v1/{owner}/{name}/runs/skip | Skip runs
*RunsV1Api* | [**stop_run**](docs/RunsV1Api.md#stop_run) | **POST** /api/v1/{owner}/{entity}/runs/{uuid}/stop | Stop run
*RunsV1Api* | [**stop_runs**](docs/RunsV1Api.md#stop_runs) | **POST** /api/v1/{owner}/{name}/runs/stop | Stop runs
*RunsV1Api* | [**sync_run**](docs/RunsV1Api.md#sync_run) | **POST** /api/v1/{owner}/{project}/runs/sync | Sync offline run
*RunsV1Api* | [**tag_runs**](docs/RunsV1Api.md#tag_runs) | **POST** /api/v1/{owner}/{name}/runs/tag | Tag runs
*RunsV1Api* | [**transfer_run**](docs/RunsV1Api.md#transfer_run) | **POST** /api/v1/{owner}/{project}/runs/{run.uuid}/transfer | Transfer run
*RunsV1Api* | [**transfer_runs**](docs/RunsV1Api.md#transfer_runs) | **POST** /api/v1/{owner}/{name}/runs/transfer | Transfer runs
*RunsV1Api* | [**unbookmark_run**](docs/RunsV1Api.md#unbookmark_run) | **DELETE** /api/v1/{owner}/{entity}/runs/{uuid}/unbookmark | Unbookmark run
*RunsV1Api* | [**update_run**](docs/RunsV1Api.md#update_run) | **PUT** /api/v1/{owner}/{project}/runs/{run.uuid} | Update run
*RunsV1Api* | [**upload_run_artifact**](docs/RunsV1Api.md#upload_run_artifact) | **POST** /api/v1/{owner}/{project}/runs/{uuid}/artifacts/upload | Upload an artifact file to a store via run access
*RunsV1Api* | [**upload_run_logs**](docs/RunsV1Api.md#upload_run_logs) | **POST** /api/v1/{owner}/{project}/runs/{uuid}/logs/upload | Upload a logs file to a store via run access
*SchemasV1Api* | [**no_op**](docs/SchemasV1Api.md#no_op) | **GET** /schemas | NoOp
*SearchesV1Api* | [**create_search**](docs/SearchesV1Api.md#create_search) | **POST** /api/v1/orgs/{owner}/searches | Create search
*SearchesV1Api* | [**delete_search**](docs/SearchesV1Api.md#delete_search) | **DELETE** /api/v1/orgs/{owner}/searches/{uuid} | Delete search
*SearchesV1Api* | [**get_search**](docs/SearchesV1Api.md#get_search) | **GET** /api/v1/orgs/{owner}/searches/{uuid} | Get search
*SearchesV1Api* | [**list_search_names**](docs/SearchesV1Api.md#list_search_names) | **GET** /api/v1/orgs/{owner}/searches/names | List search names
*SearchesV1Api* | [**list_searches**](docs/SearchesV1Api.md#list_searches) | **GET** /api/v1/orgs/{owner}/searches | List searches
*SearchesV1Api* | [**patch_search**](docs/SearchesV1Api.md#patch_search) | **PATCH** /api/v1/orgs/{owner}/searches/{search.uuid} | Patch search
*SearchesV1Api* | [**update_search**](docs/SearchesV1Api.md#update_search) | **PUT** /api/v1/orgs/{owner}/searches/{search.uuid} | Update search
*ServiceAccountsV1Api* | [**create_service_account**](docs/ServiceAccountsV1Api.md#create_service_account) | **POST** /api/v1/orgs/{owner}/sa | Create service account
*ServiceAccountsV1Api* | [**create_service_account_token**](docs/ServiceAccountsV1Api.md#create_service_account_token) | **POST** /api/v1/orgs/{owner}/sa/{entity}/tokens | Create service account token
*ServiceAccountsV1Api* | [**delete_service_account**](docs/ServiceAccountsV1Api.md#delete_service_account) | **DELETE** /api/v1/orgs/{owner}/sa/{uuid} | Delete service account
*ServiceAccountsV1Api* | [**delete_service_account_token**](docs/ServiceAccountsV1Api.md#delete_service_account_token) | **DELETE** /api/v1/orgs/{owner}/sa/{entity}/tokens/{uuid} | Delete service account token
*ServiceAccountsV1Api* | [**get_service_account**](docs/ServiceAccountsV1Api.md#get_service_account) | **GET** /api/v1/orgs/{owner}/sa/{uuid} | Get service account
*ServiceAccountsV1Api* | [**get_service_account_token**](docs/ServiceAccountsV1Api.md#get_service_account_token) | **GET** /api/v1/orgs/{owner}/sa/{entity}/tokens/{uuid} | Get service account token
*ServiceAccountsV1Api* | [**list_service_account_names**](docs/ServiceAccountsV1Api.md#list_service_account_names) | **GET** /api/v1/orgs/{owner}/sa/names | List service accounts names
*ServiceAccountsV1Api* | [**list_service_account_tokens**](docs/ServiceAccountsV1Api.md#list_service_account_tokens) | **GET** /api/v1/orgs/{owner}/sa/{uuid}/tokens | List service account tokens
*ServiceAccountsV1Api* | [**list_service_accounts**](docs/ServiceAccountsV1Api.md#list_service_accounts) | **GET** /api/v1/orgs/{owner}/sa | List service accounts
*ServiceAccountsV1Api* | [**patch_service_account**](docs/ServiceAccountsV1Api.md#patch_service_account) | **PATCH** /api/v1/orgs/{owner}/sa/{sa.uuid} | Patch service account
*ServiceAccountsV1Api* | [**patch_service_account_token**](docs/ServiceAccountsV1Api.md#patch_service_account_token) | **PATCH** /api/v1/orgs/{owner}/sa/{entity}/tokens/{token.uuid} | Patch service account token
*ServiceAccountsV1Api* | [**update_service_account**](docs/ServiceAccountsV1Api.md#update_service_account) | **PUT** /api/v1/orgs/{owner}/sa/{sa.uuid} | Update service account
*ServiceAccountsV1Api* | [**update_service_account_token**](docs/ServiceAccountsV1Api.md#update_service_account_token) | **PUT** /api/v1/orgs/{owner}/sa/{entity}/tokens/{token.uuid} | Update service account token
*TagsV1Api* | [**create_tag**](docs/TagsV1Api.md#create_tag) | **POST** /api/v1/orgs/{owner}/tags | Create tag
*TagsV1Api* | [**delete_tag**](docs/TagsV1Api.md#delete_tag) | **DELETE** /api/v1/orgs/{owner}/tags/{uuid} | Delete tag
*TagsV1Api* | [**get_tag**](docs/TagsV1Api.md#get_tag) | **GET** /api/v1/orgs/{owner}/tags/{uuid} | Get tag
*TagsV1Api* | [**list_tags**](docs/TagsV1Api.md#list_tags) | **GET** /api/v1/orgs/{owner}/tags | List tags
*TagsV1Api* | [**load_tags**](docs/TagsV1Api.md#load_tags) | **GET** /api/v1/orgs/{owner}/tags/load | Load tags
*TagsV1Api* | [**patch_tag**](docs/TagsV1Api.md#patch_tag) | **PATCH** /api/v1/orgs/{owner}/tags/{tag.uuid} | Patch tag
*TagsV1Api* | [**sync_tags**](docs/TagsV1Api.md#sync_tags) | **POST** /api/v1/orgs/{owner}/tags/sync | Sync tags
*TagsV1Api* | [**update_tag**](docs/TagsV1Api.md#update_tag) | **PUT** /api/v1/orgs/{owner}/tags/{tag.uuid} | Update tag
*TeamsV1Api* | [**approve_team_runs**](docs/TeamsV1Api.md#approve_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/approve | Approve cross-project runs selection
*TeamsV1Api* | [**archive_team_runs**](docs/TeamsV1Api.md#archive_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/archive | Archive cross-project runs selection
*TeamsV1Api* | [**bookmark_team_runs**](docs/TeamsV1Api.md#bookmark_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/bookmark | Bookmark cross-project runs selection
*TeamsV1Api* | [**create_team**](docs/TeamsV1Api.md#create_team) | **POST** /api/v1/orgs/{owner}/teams | Create team
*TeamsV1Api* | [**create_team_member**](docs/TeamsV1Api.md#create_team_member) | **POST** /api/v1/orgs/{owner}/teams/{team}/members | Create team member
*TeamsV1Api* | [**delete_team**](docs/TeamsV1Api.md#delete_team) | **DELETE** /api/v1/orgs/{owner}/teams/{name} | Delete team
*TeamsV1Api* | [**delete_team_member**](docs/TeamsV1Api.md#delete_team_member) | **DELETE** /api/v1/orgs/{owner}/teams/{team}/members/{user} | Delete team member details
*TeamsV1Api* | [**delete_team_runs**](docs/TeamsV1Api.md#delete_team_runs) | **DELETE** /api/v1/orgs/{owner}/teams/{name}/runs/delete | Delete cross-project runs selection
*TeamsV1Api* | [**get_team**](docs/TeamsV1Api.md#get_team) | **GET** /api/v1/orgs/{owner}/teams/{name} | Get team
*TeamsV1Api* | [**get_team_activities**](docs/TeamsV1Api.md#get_team_activities) | **GET** /api/v1/orgs/{owner}/teams/{name}/activities | Get organization activities
*TeamsV1Api* | [**get_team_member**](docs/TeamsV1Api.md#get_team_member) | **GET** /api/v1/orgs/{owner}/teams/{team}/members/{user} | Get team member details
*TeamsV1Api* | [**get_team_multi_run_events**](docs/TeamsV1Api.md#get_team_multi_run_events) | **GET** /streams/v1/{namespace}/orgs/{owner}/teams/{entity}/runs/multi/events/{kind} | Get multi runs events
*TeamsV1Api* | [**get_team_multi_run_importance**](docs/TeamsV1Api.md#get_team_multi_run_importance) | **POST** /streams/v1/{namespace}/orgs/{owner}/teams/{entity}/runs/multi/importance | Get multi run importance
*TeamsV1Api* | [**get_team_run**](docs/TeamsV1Api.md#get_team_run) | **GET** /api/v1/orgs/{owner}/teams/{entity}/runs/{uuid} | Get a run in a team
*TeamsV1Api* | [**get_team_runs**](docs/TeamsV1Api.md#get_team_runs) | **GET** /api/v1/orgs/{owner}/teams/{name}/runs | Get all runs in a team
*TeamsV1Api* | [**get_team_runs_artifacts_lineage**](docs/TeamsV1Api.md#get_team_runs_artifacts_lineage) | **GET** /api/v1/orgs/{owner}/teams/{name}/runs/lineage/artifacts | Get runs artifacts lineage
*TeamsV1Api* | [**get_team_stats**](docs/TeamsV1Api.md#get_team_stats) | **GET** /api/v1/orgs/{owner}/teams/{name}/stats | Get team stats
*TeamsV1Api* | [**get_team_versions**](docs/TeamsV1Api.md#get_team_versions) | **GET** /api/v1/orgs/{owner}/teams/{entity}/versions/{kind} | Get all runs in a team
*TeamsV1Api* | [**invalidate_team_runs**](docs/TeamsV1Api.md#invalidate_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/invalidate | Invalidate cross-project runs selection
*TeamsV1Api* | [**list_team_members**](docs/TeamsV1Api.md#list_team_members) | **GET** /api/v1/orgs/{owner}/teams/{name}/members | Get team members
*TeamsV1Api* | [**list_team_names**](docs/TeamsV1Api.md#list_team_names) | **GET** /api/v1/orgs/{owner}/teams/names | List teams names
*TeamsV1Api* | [**list_teams**](docs/TeamsV1Api.md#list_teams) | **GET** /api/v1/orgs/{owner}/teams | List teams
*TeamsV1Api* | [**patch_team**](docs/TeamsV1Api.md#patch_team) | **PATCH** /api/v1/orgs/{owner}/teams/{team.name} | Patch team
*TeamsV1Api* | [**patch_team_member**](docs/TeamsV1Api.md#patch_team_member) | **PATCH** /api/v1/orgs/{owner}/teams/{team}/members/{member.user} | Patch team member
*TeamsV1Api* | [**restore_team_runs**](docs/TeamsV1Api.md#restore_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/restore | Restore cross-project runs selection
*TeamsV1Api* | [**skip_team_runs**](docs/TeamsV1Api.md#skip_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/Skip | Skip cross-project runs selection
*TeamsV1Api* | [**stop_team_runs**](docs/TeamsV1Api.md#stop_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/stop | Stop cross-project runs selection
*TeamsV1Api* | [**tag_team_runs**](docs/TeamsV1Api.md#tag_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/tag | Tag cross-project runs selection
*TeamsV1Api* | [**transfer_team_runs**](docs/TeamsV1Api.md#transfer_team_runs) | **POST** /api/v1/orgs/{owner}/teams/{name}/runs/transfer | Transfer cross-project runs selection to a new project
*TeamsV1Api* | [**update_team**](docs/TeamsV1Api.md#update_team) | **PUT** /api/v1/orgs/{owner}/teams/{team.name} | Update team
*TeamsV1Api* | [**update_team_member**](docs/TeamsV1Api.md#update_team_member) | **PUT** /api/v1/orgs/{owner}/teams/{team}/members/{member.user} | Update team member
*UsersV1Api* | [**create_token**](docs/UsersV1Api.md#create_token) | **POST** /api/v1/users/tokens | Create token
*UsersV1Api* | [**delete_token**](docs/UsersV1Api.md#delete_token) | **DELETE** /api/v1/users/tokens/{uuid} | Delete token
*UsersV1Api* | [**get_history**](docs/UsersV1Api.md#get_history) | **GET** /api/v1/users/history | User History
*UsersV1Api* | [**get_suggestions**](docs/UsersV1Api.md#get_suggestions) | **GET** /api/v1/users/suggestions | User suggestions
*UsersV1Api* | [**get_token**](docs/UsersV1Api.md#get_token) | **GET** /api/v1/users/tokens/{uuid} | Get token
*UsersV1Api* | [**get_user**](docs/UsersV1Api.md#get_user) | **GET** /api/v1/users | Get current user
*UsersV1Api* | [**get_workspaces**](docs/UsersV1Api.md#get_workspaces) | **GET** /api/v1/users/workspaces | User workspaces
*UsersV1Api* | [**list_tokens**](docs/UsersV1Api.md#list_tokens) | **GET** /api/v1/users/tokens | List tokens
*UsersV1Api* | [**patch_token**](docs/UsersV1Api.md#patch_token) | **PATCH** /api/v1/users/tokens/{token.uuid} | Patch token
*UsersV1Api* | [**patch_user**](docs/UsersV1Api.md#patch_user) | **PATCH** /api/v1/users | Patch current user
*UsersV1Api* | [**update_token**](docs/UsersV1Api.md#update_token) | **PUT** /api/v1/users/tokens/{token.uuid} | Update token
*UsersV1Api* | [**update_user**](docs/UsersV1Api.md#update_user) | **PUT** /api/v1/users | Update current user
*VersionsV1Api* | [**get_compatibility**](docs/VersionsV1Api.md#get_compatibility) | **GET** /api/v1/compatibility/{uuid}/{version}/{service} | Get compatibility versions
*VersionsV1Api* | [**get_installation**](docs/VersionsV1Api.md#get_installation) | **GET** /api/v1/installation | Get installation versions
*VersionsV1Api* | [**get_log_handler**](docs/VersionsV1Api.md#get_log_handler) | **GET** /api/v1/log_handler | Get log handler versions


## Documentation For Models

 - [AgentStateResponseAgentState](docs/AgentStateResponseAgentState.md)
 - [ProtobufAny](docs/ProtobufAny.md)
 - [ProtobufNullValue](docs/ProtobufNullValue.md)
 - [RuntimeError](docs/RuntimeError.md)
 - [SearchView](docs/SearchView.md)
 - [V1Activity](docs/V1Activity.md)
 - [V1Agent](docs/V1Agent.md)
 - [V1AgentReconcileBodyRequest](docs/V1AgentReconcileBodyRequest.md)
 - [V1AgentStateResponse](docs/V1AgentStateResponse.md)
 - [V1AgentStatusBodyRequest](docs/V1AgentStatusBodyRequest.md)
 - [V1AnalyticsSpec](docs/V1AnalyticsSpec.md)
 - [V1ArtifactKind](docs/V1ArtifactKind.md)
 - [V1ArtifactTree](docs/V1ArtifactTree.md)
 - [V1ArtifactsMount](docs/V1ArtifactsMount.md)
 - [V1ArtifactsType](docs/V1ArtifactsType.md)
 - [V1Auth](docs/V1Auth.md)
 - [V1AuthType](docs/V1AuthType.md)
 - [V1AverageStoppingPolicy](docs/V1AverageStoppingPolicy.md)
 - [V1Bayes](docs/V1Bayes.md)
 - [V1BucketConnection](docs/V1BucketConnection.md)
 - [V1Build](docs/V1Build.md)
 - [V1Cache](docs/V1Cache.md)
 - [V1ClaimConnection](docs/V1ClaimConnection.md)
 - [V1CleanPodPolicy](docs/V1CleanPodPolicy.md)
 - [V1Cloning](docs/V1Cloning.md)
 - [V1CloningKind](docs/V1CloningKind.md)
 - [V1Compatibility](docs/V1Compatibility.md)
 - [V1CompiledOperation](docs/V1CompiledOperation.md)
 - [V1Component](docs/V1Component.md)
 - [V1ConnectionKind](docs/V1ConnectionKind.md)
 - [V1ConnectionResource](docs/V1ConnectionResource.md)
 - [V1ConnectionResponse](docs/V1ConnectionResponse.md)
 - [V1ConnectionSchema](docs/V1ConnectionSchema.md)
 - [V1ConnectionType](docs/V1ConnectionType.md)
 - [V1Credentials](docs/V1Credentials.md)
 - [V1CronSchedule](docs/V1CronSchedule.md)
 - [V1Dag](docs/V1Dag.md)
 - [V1DagRef](docs/V1DagRef.md)
 - [V1Dashboard](docs/V1Dashboard.md)
 - [V1DashboardSpec](docs/V1DashboardSpec.md)
 - [V1DaskCluster](docs/V1DaskCluster.md)
 - [V1DaskReplica](docs/V1DaskReplica.md)
 - [V1DateTimeSchedule](docs/V1DateTimeSchedule.md)
 - [V1DiffStoppingPolicy](docs/V1DiffStoppingPolicy.md)
 - [V1DockerfileType](docs/V1DockerfileType.md)
 - [V1EarlyStopping](docs/V1EarlyStopping.md)
 - [V1EntitiesTags](docs/V1EntitiesTags.md)
 - [V1EntitiesTransfer](docs/V1EntitiesTransfer.md)
 - [V1EntityNotificationBody](docs/V1EntityNotificationBody.md)
 - [V1EntityStageBodyRequest](docs/V1EntityStageBodyRequest.md)
 - [V1EntityStatusBodyRequest](docs/V1EntityStatusBodyRequest.md)
 - [V1Environment](docs/V1Environment.md)
 - [V1Event](docs/V1Event.md)
 - [V1EventArtifact](docs/V1EventArtifact.md)
 - [V1EventAudio](docs/V1EventAudio.md)
 - [V1EventChart](docs/V1EventChart.md)
 - [V1EventChartKind](docs/V1EventChartKind.md)
 - [V1EventConfusionMatrix](docs/V1EventConfusionMatrix.md)
 - [V1EventCurve](docs/V1EventCurve.md)
 - [V1EventCurveKind](docs/V1EventCurveKind.md)
 - [V1EventDataframe](docs/V1EventDataframe.md)
 - [V1EventHistogram](docs/V1EventHistogram.md)
 - [V1EventImage](docs/V1EventImage.md)
 - [V1EventKind](docs/V1EventKind.md)
 - [V1EventModel](docs/V1EventModel.md)
 - [V1EventSpan](docs/V1EventSpan.md)
 - [V1EventSpanKind](docs/V1EventSpanKind.md)
 - [V1EventTrigger](docs/V1EventTrigger.md)
 - [V1EventType](docs/V1EventType.md)
 - [V1EventVideo](docs/V1EventVideo.md)
 - [V1EventsResponse](docs/V1EventsResponse.md)
 - [V1FailureEarlyStopping](docs/V1FailureEarlyStopping.md)
 - [V1FileType](docs/V1FileType.md)
 - [V1GcsType](docs/V1GcsType.md)
 - [V1GitConnection](docs/V1GitConnection.md)
 - [V1GitType](docs/V1GitType.md)
 - [V1GridSearch](docs/V1GridSearch.md)
 - [V1Hook](docs/V1Hook.md)
 - [V1HostConnection](docs/V1HostConnection.md)
 - [V1HostPathConnection](docs/V1HostPathConnection.md)
 - [V1HpChoice](docs/V1HpChoice.md)
 - [V1HpDateRange](docs/V1HpDateRange.md)
 - [V1HpDateTimeRange](docs/V1HpDateTimeRange.md)
 - [V1HpGeomSpace](docs/V1HpGeomSpace.md)
 - [V1HpLinSpace](docs/V1HpLinSpace.md)
 - [V1HpLogNormal](docs/V1HpLogNormal.md)
 - [V1HpLogSpace](docs/V1HpLogSpace.md)
 - [V1HpLogUniform](docs/V1HpLogUniform.md)
 - [V1HpNormal](docs/V1HpNormal.md)
 - [V1HpPChoice](docs/V1HpPChoice.md)
 - [V1HpParams](docs/V1HpParams.md)
 - [V1HpQLogNormal](docs/V1HpQLogNormal.md)
 - [V1HpQLogUniform](docs/V1HpQLogUniform.md)
 - [V1HpQNormal](docs/V1HpQNormal.md)
 - [V1HpQUniform](docs/V1HpQUniform.md)
 - [V1HpRange](docs/V1HpRange.md)
 - [V1HpUniform](docs/V1HpUniform.md)
 - [V1HubRef](docs/V1HubRef.md)
 - [V1Hyperband](docs/V1Hyperband.md)
 - [V1Hyperopt](docs/V1Hyperopt.md)
 - [V1HyperoptAlgorithms](docs/V1HyperoptAlgorithms.md)
 - [V1IO](docs/V1IO.md)
 - [V1Init](docs/V1Init.md)
 - [V1Installation](docs/V1Installation.md)
 - [V1IntervalSchedule](docs/V1IntervalSchedule.md)
 - [V1Iterative](docs/V1Iterative.md)
 - [V1Job](docs/V1Job.md)
 - [V1Join](docs/V1Join.md)
 - [V1JoinParam](docs/V1JoinParam.md)
 - [V1KFReplica](docs/V1KFReplica.md)
 - [V1ListActivitiesResponse](docs/V1ListActivitiesResponse.md)
 - [V1ListAgentsResponse](docs/V1ListAgentsResponse.md)
 - [V1ListBookmarksResponse](docs/V1ListBookmarksResponse.md)
 - [V1ListConnectionsResponse](docs/V1ListConnectionsResponse.md)
 - [V1ListDashboardsResponse](docs/V1ListDashboardsResponse.md)
 - [V1ListOrganizationMembersResponse](docs/V1ListOrganizationMembersResponse.md)
 - [V1ListOrganizationsResponse](docs/V1ListOrganizationsResponse.md)
 - [V1ListPoliciesResponse](docs/V1ListPoliciesResponse.md)
 - [V1ListPresetsResponse](docs/V1ListPresetsResponse.md)
 - [V1ListProjectVersionsResponse](docs/V1ListProjectVersionsResponse.md)
 - [V1ListProjectsResponse](docs/V1ListProjectsResponse.md)
 - [V1ListQueuesResponse](docs/V1ListQueuesResponse.md)
 - [V1ListRunArtifactsResponse](docs/V1ListRunArtifactsResponse.md)
 - [V1ListRunConnectionsResponse](docs/V1ListRunConnectionsResponse.md)
 - [V1ListRunEdgesResponse](docs/V1ListRunEdgesResponse.md)
 - [V1ListRunsResponse](docs/V1ListRunsResponse.md)
 - [V1ListSearchesResponse](docs/V1ListSearchesResponse.md)
 - [V1ListServiceAccountsResponse](docs/V1ListServiceAccountsResponse.md)
 - [V1ListTagsResponse](docs/V1ListTagsResponse.md)
 - [V1ListTeamMembersResponse](docs/V1ListTeamMembersResponse.md)
 - [V1ListTeamsResponse](docs/V1ListTeamsResponse.md)
 - [V1ListTokenResponse](docs/V1ListTokenResponse.md)
 - [V1Log](docs/V1Log.md)
 - [V1LogHandler](docs/V1LogHandler.md)
 - [V1Logs](docs/V1Logs.md)
 - [V1MPIJob](docs/V1MPIJob.md)
 - [V1ManagedBy](docs/V1ManagedBy.md)
 - [V1Mapping](docs/V1Mapping.md)
 - [V1Matrix](docs/V1Matrix.md)
 - [V1MatrixKind](docs/V1MatrixKind.md)
 - [V1MedianStoppingPolicy](docs/V1MedianStoppingPolicy.md)
 - [V1MetricEarlyStopping](docs/V1MetricEarlyStopping.md)
 - [V1MultiEventsResponse](docs/V1MultiEventsResponse.md)
 - [V1Notification](docs/V1Notification.md)
 - [V1Operation](docs/V1Operation.md)
 - [V1OperationBody](docs/V1OperationBody.md)
 - [V1Optimization](docs/V1Optimization.md)
 - [V1OptimizationMetric](docs/V1OptimizationMetric.md)
 - [V1OptimizationResource](docs/V1OptimizationResource.md)
 - [V1Organization](docs/V1Organization.md)
 - [V1OrganizationMember](docs/V1OrganizationMember.md)
 - [V1Param](docs/V1Param.md)
 - [V1PasswordChange](docs/V1PasswordChange.md)
 - [V1PatchStrategy](docs/V1PatchStrategy.md)
 - [V1PathRef](docs/V1PathRef.md)
 - [V1Pipeline](docs/V1Pipeline.md)
 - [V1PipelineKind](docs/V1PipelineKind.md)
 - [V1Plugins](docs/V1Plugins.md)
 - [V1Policy](docs/V1Policy.md)
 - [V1PolyaxonInitContainer](docs/V1PolyaxonInitContainer.md)
 - [V1PolyaxonSidecarContainer](docs/V1PolyaxonSidecarContainer.md)
 - [V1Preset](docs/V1Preset.md)
 - [V1PresetSettings](docs/V1PresetSettings.md)
 - [V1Project](docs/V1Project.md)
 - [V1ProjectSettings](docs/V1ProjectSettings.md)
 - [V1ProjectVersion](docs/V1ProjectVersion.md)
 - [V1ProjectVersionKind](docs/V1ProjectVersionKind.md)
 - [V1PytorchElasticPolicy](docs/V1PytorchElasticPolicy.md)
 - [V1PytorchJob](docs/V1PytorchJob.md)
 - [V1Queue](docs/V1Queue.md)
 - [V1RandomSearch](docs/V1RandomSearch.md)
 - [V1RayCluster](docs/V1RayCluster.md)
 - [V1RayReplica](docs/V1RayReplica.md)
 - [V1Reference](docs/V1Reference.md)
 - [V1ResourceType](docs/V1ResourceType.md)
 - [V1Run](docs/V1Run.md)
 - [V1RunArtifact](docs/V1RunArtifact.md)
 - [V1RunArtifacts](docs/V1RunArtifacts.md)
 - [V1RunConnection](docs/V1RunConnection.md)
 - [V1RunEdge](docs/V1RunEdge.md)
 - [V1RunEdgeKind](docs/V1RunEdgeKind.md)
 - [V1RunEdgeLineage](docs/V1RunEdgeLineage.md)
 - [V1RunEdgesGraph](docs/V1RunEdgesGraph.md)
 - [V1RunKind](docs/V1RunKind.md)
 - [V1RunPending](docs/V1RunPending.md)
 - [V1RunReferenceCatalog](docs/V1RunReferenceCatalog.md)
 - [V1RunResources](docs/V1RunResources.md)
 - [V1RunSchema](docs/V1RunSchema.md)
 - [V1RunSettings](docs/V1RunSettings.md)
 - [V1S3Type](docs/V1S3Type.md)
 - [V1Schedule](docs/V1Schedule.md)
 - [V1ScheduleKind](docs/V1ScheduleKind.md)
 - [V1SchedulingPolicy](docs/V1SchedulingPolicy.md)
 - [V1Schemas](docs/V1Schemas.md)
 - [V1Search](docs/V1Search.md)
 - [V1SearchSpec](docs/V1SearchSpec.md)
 - [V1SectionSpec](docs/V1SectionSpec.md)
 - [V1Service](docs/V1Service.md)
 - [V1ServiceAccount](docs/V1ServiceAccount.md)
 - [V1SettingsCatalog](docs/V1SettingsCatalog.md)
 - [V1Stage](docs/V1Stage.md)
 - [V1StageCondition](docs/V1StageCondition.md)
 - [V1Stages](docs/V1Stages.md)
 - [V1Status](docs/V1Status.md)
 - [V1StatusCondition](docs/V1StatusCondition.md)
 - [V1Statuses](docs/V1Statuses.md)
 - [V1TFJob](docs/V1TFJob.md)
 - [V1Tag](docs/V1Tag.md)
 - [V1Team](docs/V1Team.md)
 - [V1TeamMember](docs/V1TeamMember.md)
 - [V1TeamSettings](docs/V1TeamSettings.md)
 - [V1Template](docs/V1Template.md)
 - [V1TensorboardType](docs/V1TensorboardType.md)
 - [V1Termination](docs/V1Termination.md)
 - [V1Token](docs/V1Token.md)
 - [V1TrialStart](docs/V1TrialStart.md)
 - [V1TriggerPolicy](docs/V1TriggerPolicy.md)
 - [V1TruncationStoppingPolicy](docs/V1TruncationStoppingPolicy.md)
 - [V1Tuner](docs/V1Tuner.md)
 - [V1UriType](docs/V1UriType.md)
 - [V1UrlRef](docs/V1UrlRef.md)
 - [V1User](docs/V1User.md)
 - [V1UserAccess](docs/V1UserAccess.md)
 - [V1UserAccessData](docs/V1UserAccessData.md)
 - [V1UserEmail](docs/V1UserEmail.md)
 - [V1UserSingup](docs/V1UserSingup.md)
 - [V1Uuids](docs/V1Uuids.md)
 - [V1Validation](docs/V1Validation.md)
 - [V1Version](docs/V1Version.md)
 - [V1WasbType](docs/V1WasbType.md)


## Documentation For Authorization


## ApiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

contact@polyaxon.com


